--- /dev/null	Sun Aug  5 23:41:08 2018
+++ new/usr/src/man/man3c/bind.3c	Sun Aug  5 23:41:08 2018
@@ -0,0 +1,125 @@
+.\"
+.\" The contents of this file are subject to the terms of the
+.\" Common Development and Distribution License (the "License").
+.\" You may not use this file except in compliance with the License.
+.\"
+.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
+.\" or http://www.opensolaris.org/os/licensing.
+.\" See the License for the specific language governing permissions
+.\" and limitations under the License.
+.\"
+.\" When distributing Covered Code, include this CDDL HEADER in each
+.\" file and include the License file at usr/src/OPENSOLARIS.LICENSE.
+.\" If applicable, add the following below this CDDL HEADER, with the
+.\" fields enclosed by brackets "[]" replaced with your own identifying
+.\" information: Portions Copyright [yyyy] [name of copyright owner]
+.\"
+.\"
+.\" Copyright 1989 AT&T
+.\" Copyright (C) 2009, Sun Microsystems, Inc. All Rights Reserved
+.\" Copyright 2018 Nexenta Systems, Inc.
+.\"
+.Dd August 2, 2018
+.Dt BIND 3C
+.Os
+.Sh NAME
+.Nm bind
+.Nd bind a name to a socket
+.Sh LIBRARY
+.Lb libc
+.Sh SYNOPSIS
+.In sys/types.h
+.In sys/socket.h
+.Ft int
+.Fo bind
+.Fa "int s"
+.Fa "const struct sockaddr *name"
+.Fa "socklen_t namelen"
+.Fc
+.Sh DESCRIPTION
+The
+.Fn bind
+function assigns a name to an unnamed socket.
+When a socket is created with
+.Xr socket 3C ,
+it exists in a name space (address family) but has no name assigned.
+The
+.Fn bind
+function requests that the name pointed to by
+.Fa name
+be assigned to the socket.
+.Sh RETURN VALUES
+Upon successful completion 0 is returned.
+Otherwise, -1
+is returned and
+.Va errno
+is set to indicate the error.
+.Sh ERRORS
+The
+.Fn bind
+function will fail if:
+.Bl -tag -width Er
+.It Bq Er EACCES
+The requested address is protected, and
+.Bq Dv PRIV_NET_PRIVADDR
+is not asserted in the effective set of the current process.
+.It Bq Er EADDRINUSE
+The specified address is already in use.
+.It Bq Er EADDRNOTAVAIL
+The specified address is not available on the local machine.
+.It Bq Er EBADF
+.Fa s
+is not a valid descriptor.
+.It Bq Er EINVAL
+.Fa namelen
+is not the size of a valid address for the specified address family.
+.Pp
+The socket is already bound to an address.
+.Pp
+Socket options are inconsistent with port attributes.
+.It Bq Er ENOSR
+There were insufficient STREAMS resources for the operation to complete.
+.It Bq Er ENOTSOCK
+.Fa s
+is a descriptor for a file, not a socket.
+.El
+.Pp
+The following errors are specific to binding names in the UNIX domain:
+.Bl -tag -width Er
+.It Bq Er EACCES
+Search permission is denied for a component of the path prefix of the pathname
+in
+.Fa name .
+.It Bq Er EIO
+An I/O error occurred while making the directory entry or allocating the inode.
+.It Bq Er EISDIR
+A null pathname was specified.
+.It Bq Er ELOOP
+Too many symbolic links were encountered in translating the pathname in
+.Fa name .
+.It Bq Er ENOENT
+A component of the path prefix of the pathname in
+.Fa name
+does not exist.
+.It Bq Er ENOTDIR
+A component of the path prefix of the pathname in
+.Fa name
+is not a directory.
+.It Bq Er EROFS
+The inode would reside on a read-only file system.
+.El
+.Sh MT-LEVEL
+.Sy Safe
+.Sh SEE ALSO
+.Xr unlink 2 ,
+.Xr sockaddr 3C ,
+.Xr socket 3C ,
+.Xr socket.h 3HEAD ,
+.Xr attributes 5 ,
+.Xr privileges 5
+.Sh NOTES
+Binding a name in the UNIX domain creates a socket in the file system that must
+be deleted by the caller when it is no longer needed by using
+.Xr unlink 2 .
+.Pp
+The rules used in name binding vary between communication domains.
